@@ -1,8 +1,9 @@
-import subprocess
 import os
 import errno
 import shutil
 
+from . import local
+
 
 def read_file(path):
     with open(path) as f:
@@ -20,7 +21,7 @@ copy_file = shutil.copyfile
 def copy_dir(source, destination):
     # TODO: should be pure Python, but there isn't a stdlib function
     # that allows the destination to already exist
-    subprocess.check_call(["cp", "-rT", source, destination])
+    local.run(["cp", "-rT", source, destination])
 
 
 def mkdir_p(path):
@@ -50,7 +51,7 @@ def write_files(root_dir, file_descriptions):
 
 
 def sh_script_description(path, contents):
-    return FileDescription(path, "#!/bin/sh\n{0}".format(contents), 0755, "file")
+    return FileDescription(path, "#!/bin/sh\n{0}".format(contents), 0o755, "file")
 
 
 def directory_description(path):
@@ -58,7 +59,7 @@ def directory_description(path):
 
 
 def plain_file(path, contents):
-    return FileDescription(path, contents, permissions=0644, file_type="file")
+    return FileDescription(path, contents, permissions=0o644, file_type="file")
 
 
 def symlink(path, actual_path):
