@@ -13,9 +13,9 @@ from .tarballs import extract_tarball, create_tarball
 from .indices import read_index
 from .errors import FileNotFoundError, WhackUserError
 from .tempdir import create_temporary_dir
-
-
-_whack_source_uri_suffix = ".whack-source"
+from .uris import is_local_path, is_http_uri
+from . import slugs
+from .common import SOURCE_URI_SUFFIX
 
 
 class PackageSourceNotFound(WhackUserError):
@@ -65,11 +65,9 @@ class PackageSourceFetcher(object):
             return None
             
     def _verify(self, source_name, package_source):
-        whack_source_uri_regex = \
-            r"(?:^|/|-)([^./-]*){0}$".format(re.escape(_whack_source_uri_suffix))
-        result = re.search(whack_source_uri_regex, source_name)
-        if result:
-            expected_hash = result.group(1)
+        if source_name.endswith(SOURCE_URI_SUFFIX):
+            full_name = source_name[:-len(SOURCE_URI_SUFFIX)]
+            expected_hash = slugs.split(full_name)[-1]
             actual_hash = package_source.source_hash()
             if expected_hash != actual_hash:
                 raise SourceHashMismatch(expected_hash, actual_hash)
@@ -80,12 +78,11 @@ class IndexFetcher(object):
         self._index_uri = index_uri
     
     def can_fetch(self, source_name):
-        return re.match(r"^[a-z0-9\-]+$", source_name)
+        return re.match(r"^[a-z0-9\-_]+$", source_name)
         
     def fetch(self, source_name):
         index = read_index(self._index_uri)
-        package_source_filename = source_name + _whack_source_uri_suffix
-        package_source_entry = index.find_by_name(package_source_filename)
+        package_source_entry = index.find_package_source_by_name(source_name)
         if package_source_entry is None:
             return None
         else:
@@ -105,13 +102,7 @@ class SourceControlFetcher(object):
         
 class LocalPathFetcher(object):
     def can_fetch(self, source_name):
-        return (
-            source_name.startswith("/") or
-            source_name.startswith("./") or
-            source_name.startswith("../") or 
-            source_name == "." or
-            source_name == ".."
-        )
+        return is_local_path(source_name)
         
     def fetch(self, source_name):
         if os.path.isfile(source_name):
@@ -129,7 +120,7 @@ class LocalPathFetcher(object):
 
 class HttpFetcher(object):
     def can_fetch(self, source_name):
-        return source_name.startswith("http://")
+        return is_http_uri(source_name)
         
     def fetch(self, source_name):
         def fetch_directory(temp_dir):
@@ -173,10 +164,7 @@ class PackageSource(object):
     def full_name(self):
         name = self.name()
         source_hash = self.source_hash()
-        if name is None:
-            return source_hash
-        else:
-            return "{0}-{1}".format(name, source_hash)
+        return slugs.join([name, source_hash])
     
     def source_hash(self):
         hasher = Hasher()
@@ -235,7 +223,7 @@ class DictBackedPackageDescription(object):
         self._values = values
         
     def name(self):
-        return self._values.get("name", None)
+        return self._values.get("name", "unknown")
         
     def param_slug(self):
         return self._values.get("paramSlug", None)
@@ -254,7 +242,7 @@ def create_source_tarball(package_source, tarball_dir):
     with create_temporary_dir() as source_dir:
         package_source.write_to(source_dir)
         full_name = package_source.full_name()
-        filename = "{0}{1}".format(full_name, _whack_source_uri_suffix)
+        filename = "{0}{1}".format(full_name, SOURCE_URI_SUFFIX)
         path = os.path.join(tarball_dir, filename)
         create_tarball(path, source_dir)
         return SourceTarball(full_name, path)
